django-siteajax documentation
=============================
https://github.com/idlesign/django-siteajax



Description
-----------

*Reusable application for Django bridging client and server sides*

Streamline your server and client interaction using declarative techniques
in your HTML and helpful abstractions from `siteajax` in your Python code.

.. note::
    The client side of `siteajax` is powered by `htmx` (the successor of `intercooler.js`) - https://htmx.org/


Requirements
------------

1. Python 3.7+
2. Django 2.2+



Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    advanced
